==> serverless-deployment-manager-0.1.6.tgz: package/lib/index.js <==
'use strict';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

const AWS = require('aws-sdk');

const {
  filter,
  isNil,
  contains,
  pipe,
  head,
  reduce,
  sortBy,
  concat,
  not,
  isEmpty,
  findIndex
} = require('ramda');

function stageType(stage) {
  if (/^\/.*\/(i|g|m|s|u|y)*$/.test(stage)) {
    return 1;
  } else if (isNil(stage)) {
    return 2;
  }

  return 0;
}

function testStage(stage, deploymentDefinitionStage) {
  if (isNil(deploymentDefinitionStage)) {
    return true;
  }

  let regexp;

  if (stageType(deploymentDefinitionStage) === 1) {
    const pattern = deploymentDefinitionStage.substr(1, deploymentDefinitionStage.lastIndexOf('/') - 1);
    const flag = deploymentDefinitionStage.substr(deploymentDefinitionStage.lastIndexOf('/') + 1);
    regexp = new RegExp(pattern, flag);
  } else {
    regexp = new RegExp(`^${deploymentDefinitionStage}$`);
  }

  return regexp.test(stage);
}

class DeploymentManagerPlugin {
  constructor(serverless, options) {
    this.serverless = serverless;
    this.options = options;
    this.commands = {
      validate: {
        usage: 'Validates current AWS account agains deployment configuration',
        lifecycleEvents: ['validate'],
        options: {
          stage: {
            usage: ' "--stage dev" or "-s dev"',
            required: true,
            shortcut: 's'
          }
        }
      }
    };
    this.hooks = {
      'validate:validate': this.validateStageAndAccount.bind(this),
      'before:package:initialize': this.validateStageAndAccount.bind(this),
      'before:deploy:function:initialize': this.validateStageAndAccount.bind(this)
    };
  }

  validateStageAndAccount() {
    var _this = this;

    return _asyncToGenerator(function* () {
      const {
        processedInput,
        service
      } = _this.serverless;

      if (isNil(service.custom) || isNil(service.custom.deployment)) {
        throw new Error('[serverless-deployment-manager] service.custom.deployment definition is missing');
      }

      const deploymentDefinition = pipe(filter(({
        stage
      }) => testStage(processedInput.options.stage, stage)), sortBy(({
        stage
      }) => stageType(stage)), reduce((acc, item) => {
        const accountIds = item.accountIds || [];
        const regions = item.regions || [];
        const currentItem = {
          stage: item.stage,
          accountIds: not(isNil(item.accountId)) ? [item.accountId] : accountIds,
          regions: not(isNil(item.region)) ? [item.region] : regions
        };
        const existingItemIndex = findIndex(({
          stage
        }) => currentItem.stage === stage, acc);

        if (existingItemIndex > -1) {
          acc[existingItemIndex].accountIds = concat(acc[existingItemIndex].accountIds, currentItem.accountIds);
          acc[existingItemIndex].regions = concat(acc[existingItemIndex].regions, currentItem.regions);
        } else {
          acc = concat(acc, [currentItem]);
        }

        return acc;
      }, []), head)(service.custom.deployment);

      if (isNil(deploymentDefinition)) {
        throw new Error(`[serverless-deployment-manager] stage '${processedInput.options.stage}' cannot be deployed`);
      }

      if (not(isEmpty(deploymentDefinition.accountIds))) {
        const sts = new AWS.STS({
          region: processedInput.options.region
        });
        const {
          Account
        } = yield sts.getCallerIdentity().promise();

        if (not(contains(Account, deploymentDefinition.accountIds))) {
          throw new Error(`[serverless-deployment-manager] stage '${processedInput.options.stage}' cannot be deployed to account '${Account}'`);
        }
      }

      if (not(isEmpty(deploymentDefinition.regions))) {
        if (not(contains(processedInput.options.region, deploymentDefinition.regions))) {
          throw new Error(`[serverless-deployment-manager] stage '${processedInput.options.stage}' cannot be deployed to region '${processedInput.options.region}'`);
        }
      }
    })();
  }

}

module.exports = DeploymentManagerPlugin;

==> serverless-deployment-manager-0.2.0.tgz: package/lib/index.js <==
'use strict';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

const AWS = require('aws-sdk');

const {
  filter,
  isNil,
  contains,
  pipe,
  head,
  reduce,
  sortBy,
  concat,
  not,
  isEmpty,
  findIndex
} = require('ramda');

function stageType(stage) {
  if (/^\/.*\/(i|g|m|s|u|y)*$/.test(stage)) {
    return 1;
  } else if (isNil(stage)) {
    return 2;
  }

  return 0;
}

function testStage(stage, deploymentDefinitionStage) {
  if (isNil(deploymentDefinitionStage)) {
    return true;
  }

  let regexp;

  if (stageType(deploymentDefinitionStage) === 1) {
    const pattern = deploymentDefinitionStage.substr(1, deploymentDefinitionStage.lastIndexOf('/') - 1);
    const flag = deploymentDefinitionStage.substr(deploymentDefinitionStage.lastIndexOf('/') + 1);
    regexp = new RegExp(pattern, flag);
  } else {
    regexp = new RegExp(`^${deploymentDefinitionStage}$`);
  }

  return regexp.test(stage);
}

class DeploymentManagerPlugin {
  constructor(serverless, options) {
    this.serverless = serverless;
    this.options = options;
    this.commands = {
      validate: {
        usage: 'Validates current AWS account agains deployment configuration',
        lifecycleEvents: ['validate'],
        options: {
          stage: {
            usage: ' "--stage dev" or "-s dev"',
            required: true,
            shortcut: 's'
          }
        }
      }
    };
    this.hooks = {
      'validate:validate': this.validateStageAndAccount.bind(this),
      'before:deploy:deploy': this.validateStageAndAccount.bind(this),
      'before:deploy:function:initialize': this.validateStageAndAccount.bind(this)
    };
  }

  validateStageAndAccount() {
    var _this = this;

    return _asyncToGenerator(function* () {
      const {
        processedInput,
        service
      } = _this.serverless;

      if (isNil(service.custom) || isNil(service.custom.deployment)) {
        throw new Error('[serverless-deployment-manager] service.custom.deployment definition is missing');
      }

      const deploymentDefinition = pipe(filter(({
        stage
      }) => testStage(processedInput.options.stage, stage)), sortBy(({
        stage
      }) => stageType(stage)), reduce((acc, item) => {
        const accountIds = item.accountIds || [];
        const regions = item.regions || [];
        const currentItem = {
          stage: item.stage,
          accountIds: not(isNil(item.accountId)) ? [item.accountId] : accountIds,
          regions: not(isNil(item.region)) ? [item.region] : regions
        };
        const existingItemIndex = findIndex(({
          stage
        }) => currentItem.stage === stage, acc);

        if (existingItemIndex > -1) {
          acc[existingItemIndex].accountIds = concat(acc[existingItemIndex].accountIds, currentItem.accountIds);
          acc[existingItemIndex].regions = concat(acc[existingItemIndex].regions, currentItem.regions);
        } else {
          acc = concat(acc, [currentItem]);
        }

        return acc;
      }, []), head)(service.custom.deployment);

      if (isNil(deploymentDefinition)) {
        throw new Error(`[serverless-deployment-manager] stage '${processedInput.options.stage}' cannot be deployed`);
      }

      if (not(isEmpty(deploymentDefinition.accountIds))) {
        const sts = new AWS.STS({
          region: processedInput.options.region
        });
        const {
          Account
        } = yield sts.getCallerIdentity().promise();

        if (not(contains(Account, deploymentDefinition.accountIds))) {
          throw new Error(`[serverless-deployment-manager] stage '${processedInput.options.stage}' cannot be deployed to account '${Account}'`);
        }
      }

      if (not(isEmpty(deploymentDefinition.regions))) {
        if (not(contains(processedInput.options.region, deploymentDefinition.regions))) {
          throw new Error(`[serverless-deployment-manager] stage '${processedInput.options.stage}' cannot be deployed to region '${processedInput.options.region}'`);
        }
      }
    })();
  }

}

module.exports = DeploymentManagerPlugin;
